#! /bin/sh

SCRIPT_PATH=`pwd`/`dirname $0`

if [ ! -e xqts_env ]; then
    mkdir xqts_env
fi

if [ ! -e xqts_env_t ]; then
    mkdir xqts_env_t
fi

if [ ! -z "$1" ]; then
    XQTS_LOCATION="$1"
    shift
fi
if [ -z "$XQTS_LOCATION" ]; then
    XQTS_LOCATION="$SCRIPT_PATH/XQTS/XQTSCatalog.xml"
fi
if [ ! -f $XQTS_LOCATION ]; then
    echo "The XQuery test suite cannot be found. You may need to pass the location as an argument, or set \$XQTS_LOCATION"
    exit 1
fi

if [ ! -z "$1" ]; then
    XQUTS_LOCATION="$1"
    shift
fi
if [ -z "$XQUTS_LOCATION" ]; then
    XQUTS_LOCATION="$SCRIPT_PATH/XQUTS/XQUTSCatalog.xml"
fi
if [ ! -f $XQUTS_LOCATION ]; then
    echo "The XQuery Update test suite cannot be found. You may need to pass the location as an argument, or set \$XQUTS_LOCATION"
    exit 1
fi

echo "XQuery Conformance Test Suite (NLS+)"
echo "========================================================================"
echo "location: $XQTS_LOCATION"
echo "errors: xqts-latest-errors"
./dbxml_xqts_runner -e $SCRIPT_PATH/xqts-errors.xml -E xqts-latest-errors.xml -h xqts_env -c xqts $XQTS_LOCATION  -s NLS+ 2>xqts-latest-errors
if [ $? != 0 ]; then echo "TESTS FAILED"; exit; fi

echo "XQuery Conformance Test Suite (NLS)"
echo "========================================================================"
echo "location: $XQTS_LOCATION"
echo "errors: xqts-latest-errors"
./dbxml_xqts_runner -e $SCRIPT_PATH/xqts-errors.xml -E xqts-latest-errors.xml -h xqts_env -c xqts $XQTS_LOCATION  -s NLS 2>xqts-latest-errors
if [ $? != 0 ]; then echo "TESTS FAILED"; exit; fi

echo "XQuery Conformance Test Suite (DLS+)"
echo "========================================================================"
echo "location: $XQTS_LOCATION"
echo "errors: xqts-latest-errors"
./dbxml_xqts_runner -e $SCRIPT_PATH/xqts-errors.xml -E xqts-latest-errors.xml -h xqts_env -c xqts $XQTS_LOCATION  -s DLS+ -p 2>xqts-latest-errors
if [ $? != 0 ]; then echo "TESTS FAILED"; exit; fi

echo "XQuery Conformance Test Suite (DLS)"
echo "========================================================================"
echo "location: $XQTS_LOCATION"
echo "errors: xqts-latest-errors"
./dbxml_xqts_runner -e $SCRIPT_PATH/xqts-errors.xml -E xqts-latest-errors.xml -h xqts_env -c xqts $XQTS_LOCATION  -s DLS -p 2>xqts-latest-errors
if [ $? != 0 ]; then echo "TESTS FAILED"; exit; fi

echo "DB XML Query Test Suite"
echo "========================================================================"
echo "location: $SCRIPT_PATH/queries/queries.xml"
echo "errors: query-latest-errors"
./dbxml_xqts_runner -E query-latest-errors.xml -h xqts_env -c query $SCRIPT_PATH/queries/queries.xml 2>query-latest-errors
if [ $? != 0 ]; then echo "TESTS FAILED"; exit; fi

echo "XQuery Update Conformance Test Suite (Non-transacted)"
echo "========================================================================"
echo "location: $XQUTS_LOCATION"
echo "errors: xquts-latest-errors"
./dbxml_xqts_runner -E xquts-latest-errors.xml -h xqts_env -c xquts $XQUTS_LOCATION -p 2>xquts-latest-errors
if [ $? != 0 ]; then echo "TESTS FAILED"; exit; fi

echo "XQuery Update Conformance Test Suite (Transacted)"
echo "========================================================================"
echo "location: $XQUTS_LOCATION"
echo "errors: xquts-latest-errors"
./dbxml_xqts_runner -E xquts-latest-errors.xml -h xqts_env_t -c xquts $XQUTS_LOCATION -p -t 2>xquts-latest-errors
if [ $? != 0 ]; then echo "TESTS FAILED"; exit; fi

echo "DB XML Update Test Suite (Non-transacted)"
echo "========================================================================"
echo "location: $SCRIPT_PATH/updates/updates.xml"
echo "errors: update-latest-errors"
./dbxml_xqts_runner -E update-latest-errors.xml -h xqts_env -c update $SCRIPT_PATH/updates/updates.xml 2>update-latest-errors
if [ $? != 0 ]; then echo "TESTS FAILED"; exit; fi

echo "DB XML Update Test Suite (Transacted)"
echo "========================================================================"
echo "location: $SCRIPT_PATH/updates/updates.xml"
echo "errors: update-latest-errors"
./dbxml_xqts_runner -E update-latest-errors.xml -h xqts_env_t -c update -t $SCRIPT_PATH/updates/updates.xml 2>update-latest-errors
if [ $? != 0 ]; then echo "TESTS FAILED"; exit; fi

